@@ -3,9 +3,9 @@ from cyberpunk_theme import constant
 
 
 # == tree theme
-def get_style():
+def get_style(**kwargs):
     style = tkstyle.Frame()
-    style.background = constant.COLOR_1
+    style.background = constant.BACKGROUND_COLOR
     style.add(_get_tree_node_style(), pattern="*FrameNode")
     style.add(_get_tree_header_style(), pattern="*frame_header")
     style.add(_get_tree_box_style(), pattern="*frame_box")
@@ -19,19 +19,19 @@ def get_style():
 # tree node
 def _get_tree_node_style():
     style = tkstyle.Frame()
-    style.background = constant.COLOR_BLACK
+    style.background = constant.BACKGROUND_COLOR
     return style
 
 
 # tree header
 def _get_tree_header_style():
     style = tkstyle.Frame()
-    style.background = constant.COLOR_BLACK
+    style.background = constant.BACKGROUND_COLOR
     return style
 
 
 # tree box
 def _get_tree_box_style():
     style = tkstyle.Frame()
-    style.background = constant.COLOR_BLACK
+    style.background = constant.BACKGROUND_COLOR
     return style
