@@ -2,11 +2,15 @@ import tkstyle
 from cyberpunk_theme import constant
 
 
-def get_style():
+def get_style(font_family=constant.FONT_FAMILY,
+              font_size=constant.FONT_SIZE):
     style = tkstyle.Menubutton()
-    style.background = "#0C1014"
+    style.font = (font_family, font_size, "normal")
+    style.background = "#121C20"
+    style.background = "#1C2024"
     style.foreground = "#B0B0B0"
-    style.activeBackground = "#1E2226"
+    style.activeBackground = "#121C20"
+    style.activeBackground = "#1C2125"
     style.activeForeground = "#ABABAB"
     style.borderWidth = 0
     style.activeBorderWidth = 0
@@ -14,5 +18,6 @@ def get_style():
     style.highlightBackground = "#101010"
     style.relief = "flat"
     style.cursor = "hand1"
-    style.font = constant.FONT_DEFAULT_FAMILY, 11, "normal"
+    style.padY = 3
+    style.width = 16
     return style
